.. _recipe_asr.defectformation:

asr.defectformation
===================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.defectformation`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.defectformation.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.defectformation

or as a python module

.. code-block:: console

   $ python -m asr.defectformation

Detailed description
--------------------
Defect formation energies.

Steps
-----


asr.defectformation
^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.defectformation.main
   